@@ -2,6 +2,7 @@ package Site;
 use Dancer2;
 use Strehler::Element::Article;
 use Strehler::Dancer2::Plugin::EX;
+use Strehler::Element::RSS::RSSChannel;
 use Data::Dumper;
 
 set layout => 'main';
@@ -18,6 +19,20 @@ get '/' => sub {
 #    template 'article', { article => \%data };
 #};
 
+get '/article/checktag/:id/:tag' => sub {
+    my $id = params->{'id'};
+    my $tag = params->{'tag'};
+    my $article = Strehler::Element::Article->new($id);
+    if($article->has_tag($tag))
+    {
+        return $article->main_title . " has tag " . $tag;
+    }
+    else
+    {
+        return $article->main_title . " hasn't tag " . $tag;
+    }
+};
+
 slug '/ex/slug/:slug', 'element';
 list '/ex/list/dummy', 'dummy_list', 'dummy';
 latest_page '/ex/mypage', 'mypage', { upper => 'upper', lower =>  'lower' };
